/**
 * @fileoverview Conditionally rendered text nodes should be wrapped in an element (generally a <span>), otherwise Google Translate will cause a browser error.
 * @author alistair-coup
 */
'use strict';

/** @type {import('eslint').Rule.RuleModule} */
module.exports = {
  meta: {
    type: 'problem',
    docs: {
      description:
        'Conditionally rendered text nodes should be wrapped in an element (generally a <span>), otherwise Google Translate can cause a browser error.',
    },
    schema: [],
    messages: {
      unexpected:
        'When rendered as a direct child of a JSX element, conditionally rendered text nodes should be wrapped in an element (generally a <span>) to prevent Google Translate causing a browser error while manipulating the DOM.',
    },
  },

  create(context) {
    function isConditionallyRendered(node) {
      if (!node.parent) {
        return false;
      }
      return (
        node.parent.type === 'ConditionalExpression' ||
        node.parent.type === 'LogicalExpression'
      );
    }

    function isChildOfJSXElement(node) {
      return (
        node.parent.parent &&
        node.parent.parent.type === 'JSXExpressionContainer' &&
        node.parent.parent.parent &&
        node.parent.parent.parent.type === 'JSXElement'
      );
    }

    return {
      Literal(node) {
        if (isConditionallyRendered(node) && isChildOfJSXElement(node)) {
          context.report({
            node,
            messageId: 'unexpected',
          });
        } else {
          return null;
        }
      },
    };
  },
};
